#
# spec file for package ghc-lua
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name lua
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.2.1
Release:        150500.1.1
Summary:        Lua, an embeddable scripting language
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
%endif

%description
This package provides bindings and types to bridge Haskell and
<https://www.lua.org/ Lua>.

The full Lua interpreter version 5.4.4 is included. Alternatively, a
system-wide Lua installation can be linked instead.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Sun Jun 19 2022 psimons@suse.com
- Update lua to version 2.2.1.
  [#]# lua-2.2.1
  Released 2022-06-19.
  - Make string-peeking independent of the current foreign
    encoding: always use char8 encoding to retrieve values of
    `LUA_PRELOAD_TABLE` and `LUA_LOADED_TABLE`.
* Sat Feb 19 2022 psimons@suse.com
- Update lua to version 2.2.0.
  [#]# lua-2.2.0
  Released 2022-02-19.
  - Update to Lua 5.4, include Lua 5.4.4 by default.
  - Removed `hardcode-reg-keys` flag: this is no longer required
    for Lua 5.4.
  - Support arbitrary number of uservalues: Lua 5.4 allows an
    arbitrary number of uservalues to be associated with userdata
    objects. The functions `lua_newuserdata`, `lua_getuservalue`,
    and `lua_setuservalue` are replaced with the new functions
    `lua_newuserdatauv`, `lua_getiuservalue`, and
    `lua_setiuservalue`, respectively.
    The function `hslua_newhsuserdata` is renamed to
    `hslua_newhsuserdatauv` and takes the number of associated
    uservalues as an additional argument.
  - Support for the new warnings system: export binding to
    `lua_warning`.
  - The function `lua_gc` now takes three data arguments of type
    CInt. This is a workaround for the fact that the C function
    has become variadic.
  - The new patterns `LUA_GCGEN` and `LUA_GCINC` are usable with
    `lua_gc` to switch to generational and incremental garbage
    collection, respectively.
* Sat Jan 29 2022 psimons@suse.com
- Update lua to version 2.1.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lua-2.1.0/src/CHANGELOG.md
* Thu Nov  4 2021 psimons@suse.com
- Update lua to version 2.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/lua-2.0.1/src/CHANGELOG.md
* Mon Nov  1 2021 psimons@suse.com
- Add lua at version 2.0.0.1.
